'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _lodash = require('lodash.isfunction');

var _lodash2 = _interopRequireDefault(_lodash);

var _core = require('../core/core');

var _core2 = _interopRequireDefault(_core);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @class Github
 * @description Github class
 * @example
 * const github = new Github({
 *  accessToken: 'your-access-token',
 * });
 *
 * github.get('some-github-route').then((data) => {
 *  console.log(data);
 * });
 */
var Github = function (_Core) {
  _inherits(Github, _Core);

  /**
   * @constructs Github
   * @description Constructs an instance of Github.
   *
   * @param {object} config - Config of class.
   * @param {string} config.accessToken - accessToken of Github.
   * @param {object} [options] - Options of class.
   *
   */
  function Github() {
    var config = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
    var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

    _classCallCheck(this, Github);

    var _this = _possibleConstructorReturn(this, (Github.__proto__ || Object.getPrototypeOf(Github)).call(this, options));

    _this.name = 'github';
    if (!config.accessToken) {
      _this.checkValidConfig(['accessToken'], config);
    }
    _this.options = {
      access_token: config.accessToken
    };
    _this.url = 'https://api.github.com';
    _this.baseApiUrl = _this.url;
    return _this;
  }

  /**
   * @memberof Github
   * @function get
   * @description Make a get request to Github api.
   *
   * @param {string} url - Url of route.
   * @param {object} [options] - Options to pass in request.
   * @param {function} [callback] - Callback to call when the request finish.
   * @return {promise}
   */


  _createClass(Github, [{
    key: 'get',
    value: function get(url) {
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
      var callback = arguments[2];

      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'GET',
        json: true,
        uri: this.baseApiUrl + '/' + url,
        qs: Object.assign(this.options, options)
      }, callback);
    }

    /**
     * @memberof Github
     * @function post
     * @description Make a post request to Github api.
     *
     * @param {string} url - Url of route.
     * @param {object} [options] - Options to pass in request.
     * @param {function} [callback] - Callback to call when the request finish.
     * @return {promise}
     */

  }, {
    key: 'post',
    value: function post(url) {
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
      var callback = arguments[2];

      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'POST',
        json: true,
        uri: this.baseApiUrl + '/' + url,
        form: Object.assign(this.options, options)
      }, callback);
    }

    /**
     * @memberof Github
     * @function delete
     * @description Make a delete request to github api.
     *
     * @param {string} url - Url of route.
     * @param {object} [options] - Options to pass in request.
     * @param {function} [callback] - Callback to call when the request finish.
     * @return {promise}
     */

  }, {
    key: 'delete',
    value: function _delete(url) {
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
      var callback = arguments[2];

      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'DELETE',
        json: true,
        uri: this.baseApiUrl + '/' + url,
        qs: Object.assign(this.options, options)
      }, callback);
    }
  }]);

  return Github;
}(_core2.default);

exports.default = Github;