'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _lodash = require('lodash.isfunction');

var _lodash2 = _interopRequireDefault(_lodash);

var _core = require('../core/core');

var _core2 = _interopRequireDefault(_core);

var _stream = require('./stream');

var _stream2 = _interopRequireDefault(_stream);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @class Instagram
 * @description Instagram class
 * @example
 * const instagram = new Instagram({
 *  clientId: 'your-client-id',
 *  accessToken: 'your-access-token',
 * });
 *
 * instagram.get('some-instagram-route').then((data) => {
 *  console.log(data);
 * });
 *
 * // Streaming can be used on all endpoints taking MIN_TAG_ID as parameter
 * const stream = instagram.stream('tags/:tag-name/media/recent');
 *
 * stream.on('message', (message) => {
 *  console.log(message);
 * });
 */
var Instagram = function (_Core) {
  _inherits(Instagram, _Core);

  /**
   * @constructs Instagram
   * @description Constructs an instance of Instagram.
   *
   * @param {object} config - Config of class.
   * @param {string} config.clientId - clientId of Instagram app.
   * @param {string} config.accessToken - appSecret of Instagram app.
   * @param {object} [options] - Options of class.
   *
   */
  function Instagram() {
    var config = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
    var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

    _classCallCheck(this, Instagram);

    var _this = _possibleConstructorReturn(this, (Instagram.__proto__ || Object.getPrototypeOf(Instagram)).call(this, options));

    _this.name = 'instagram';
    _this.checkValidConfig(['clientId', 'accessToken'], config);
    _this.options = {
      client_id: config.clientId,
      access_token: config.accessToken
    };
    _this.url = 'https://api.instagram.com';
    _this.version = options.version || 'v1';
    _this.baseApiUrl = _this.url + '/' + _this.version;
    return _this;
  }

  /**
   * @memberof Instagram
   * @function get
   * @description Make a get request to instagram api.
   *
   * @param {string} url - Url of route.
   * @param {object} [options] - Options to pass in request.
   * @param {function} [callback] - Callback to call when the request finish.
   * @return {promise}
   */


  _createClass(Instagram, [{
    key: 'get',
    value: function get(url, options, callback) {
      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'GET',
        json: true,
        uri: this.baseApiUrl + '/' + url,
        qs: Object.assign(this.options, options)
      }, callback);
    }

    /**
     * @memberof Instagram
     * @function post
     * @description Make a post request to instagram api.
     *
     * @param {string} url - Url of route.
     * @param {object} [options] - Options to pass in request.
     * @param {function} [callback] - Callback to call when the request finish.
     * @return {promise}
     */

  }, {
    key: 'post',
    value: function post(url, options, callback) {
      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'POST',
        json: true,
        uri: this.baseApiUrl + '/' + url,
        form: Object.assign(this.options, options)
      }, callback);
    }

    /**
     * @memberof Instagram
     * @function delete
     * @description Make a delete request to instagram api.
     *
     * @param {string} url - Url of route.
     * @param {object} [options] - Options to pass in request.
     * @param {function} [callback] - Callback to call when the request finish.
     * @return {promise}
     */

  }, {
    key: 'delete',
    value: function _delete(url, options, callback) {
      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'DELETE',
        json: true,
        uri: this.baseApiUrl + '/' + url,
        qs: Object.assign(this.options, options)
      }, callback);
    }

    /**
     * @memberof Instagram
     * @function stream
     * @description Create a new instagram stream.<br />
     * Streaming can be used on all endpoints taking MIN_TAG_ID as parameter.
     *
     * @param  {string} url
     * @param  {Object} [options]
     * @return {InstagramStream} A new instagram stream.
     */

  }, {
    key: 'stream',
    value: function stream(url, options) {
      return new _stream2.default(this, url, options);
    }
  }]);

  return Instagram;
}(_core2.default);

exports.default = Instagram;