'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _lodash = require('lodash.isfunction');

var _lodash2 = _interopRequireDefault(_lodash);

var _core = require('../core/core');

var _core2 = _interopRequireDefault(_core);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @class Tumblr
 * @description Tumblr class
 * @example
 * const tumblr = new Tumblr({
 *  consumerKey: 'your-consumer-key',
 * });
 *
 * tumblr.get('some-tumblr-route').then((data) => {
 *  console.log(data);
 * });
 */
var Tumblr = function (_Core) {
  _inherits(Tumblr, _Core);

  /**
   * @constructs Tumblr
   * @description Constructs an instance of Tumblr.
   *
   * @param {object} config - Config of class.
   * @param {string} config.consumerKey - consumerKey of Tumblr app.
   * @param {object} [options] - Options of class.
   *
   */
  function Tumblr() {
    var config = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
    var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

    _classCallCheck(this, Tumblr);

    var _this = _possibleConstructorReturn(this, (Tumblr.__proto__ || Object.getPrototypeOf(Tumblr)).call(this, options));

    _this.name = 'tumblr';
    _this.checkValidConfig(['consumerKey'], config);
    _this.options = {
      api_key: config.consumerKey
    };
    _this.url = 'https://api.tumblr.com';
    _this.version = options.version || 'v2';
    _this.baseApiUrl = _this.url + '/' + _this.version;
    return _this;
  }

  /**
   * @memberof Tumblr
   * @function get
   * @description Make a get request to tumblr api.
   *
   * @param {string} url - Url of route.
   * @param {object} [options] - Options to pass in request.
   * @param {function} [callback] - Callback to call when the request finish.
   * @return {promise}
   */


  _createClass(Tumblr, [{
    key: 'get',
    value: function get(url, options, callback) {
      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'GET',
        json: true,
        uri: this.baseApiUrl + '/' + url,
        qs: Object.assign(this.options, options)
      }, callback);
    }

    /**
     * @memberof Tumblr
     * @function post
     * @description Make a post request to tumblr api.
     *
     * @param {string} url - Url of route.
     * @param {object} [options] - Options to pass in request.
     * @param {function} [callback] - Callback to call when the request finish.
     * @return {promise}
     */

  }, {
    key: 'post',
    value: function post(url, options, callback) {
      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'POST',
        json: true,
        uri: this.baseApiUrl + '/' + url,
        form: Object.assign(this.options, options)
      }, callback);
    }
  }]);

  return Tumblr;
}(_core2.default);

exports.default = Tumblr;