'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _lodash = require('lodash.isfunction');

var _lodash2 = _interopRequireDefault(_lodash);

var _core = require('../core/core');

var _core2 = _interopRequireDefault(_core);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @class Twitter
 * @description Twitter class
 * @example
 * const twitter = new Twitter({
 *  consumerKey: 'your-app-consumer-key',
 *  consumerSecret: 'your-app-consumer-secret',
 *  accessToken: 'your-app-access-token',
 *  accessTokenSecret: 'your-app-access-token-secret',
 * });
 *
 * twitter.get('some-twitter-route').then((data) => {
 *  console.log(data);
 * });
 */
var Twitter = function (_Core) {
  _inherits(Twitter, _Core);

  /**
   * @constructs Twitter
   * @description Constructs an instance of Twitter.
   *
   * @param {object} config - Config of class.
   * @param {string} config.consumerKey - consumerKey of Twitter app.
   * @param {string} config.consumerSecret - consumerSecret of Twitter app.
   * @param {string} config.accessToken - accessToken of Twitter app.
   * @param {string} config.accessTokenSecret - accessTokenSecret of Twitter app.
   * @param {object} [options] - Options of class.
   *
   */
  function Twitter() {
    var config = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
    var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

    _classCallCheck(this, Twitter);

    var _this = _possibleConstructorReturn(this, (Twitter.__proto__ || Object.getPrototypeOf(Twitter)).call(this, options));

    _this.name = 'twitter';
    _this.checkValidConfig(['consumerKey', 'consumerSecret', 'accessToken', 'accessTokenSecret'], config);
    _this.oauth = {
      consumer_key: config.consumerKey,
      consumer_secret: config.consumerSecret,
      token: config.accessToken,
      token_secret: config.accessTokenSecret
    };
    _this.url = 'https://api.twitter.com';
    _this.version = options.version || '1.1';
    _this.baseApiUrl = _this.url + '/' + _this.version;
    return _this;
  }

  /**
   * @memberof Twitter
   * @function get
   * @description Make a get request to twitter api.
   *
   * @param {string} url - Url of route.
   * @param {object} [options] - Options to pass in request.
   * @param {function} [callback] - Callback to call when the request finish.
   * @return {promise}
   */


  _createClass(Twitter, [{
    key: 'get',
    value: function get(url) {
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
      var callback = arguments[2];

      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'GET',
        json: true,
        uri: this.baseApiUrl + '/' + url + '.json',
        oauth: this.oauth,
        qs: options
      }, callback);
    }

    /**
     * @memberof Twitter
     * @function post
     * @description Make a post request to twitter api.
     *
     * @param {string} url - Url of route.
     * @param {object} [options] - Options to pass in request.
     * @param {function} [callback] - Callback to call when the request finish.
     * @return {promise}
     */

  }, {
    key: 'post',
    value: function post(url) {
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
      var callback = arguments[2];

      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'POST',
        json: true,
        uri: this.baseApiUrl + '/' + url + '.json',
        oauth: this.oauth,
        form: options
      }, callback);
    }

    /**
     * @memberof Twitter
     * @function delete
     * @description Make a get request to twitter api.
     *
     * @param {string} url - Url of route.
     * @param {object} [options] - Options to pass in request.
     * @param {function} [callback] - Callback to call when the request finish.
     * @return {promise}
     */

  }, {
    key: 'delete',
    value: function _delete(url) {
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
      var callback = arguments[2];

      if ((0, _lodash2.default)(options)) {
        callback = options;
        options = {};
      }
      return this.request({
        method: 'DELETE',
        json: true,
        uri: this.baseApiUrl + '/' + url + '.json',
        oauth: this.oauth,
        qs: options
      }, callback);
    }
  }]);

  return Twitter;
}(_core2.default);

exports.default = Twitter;